@@ -1,66 +1,66 @@
-use v5.10;
 use strict;
 use warnings;
 
 package HTTP::Tiny::UA;
 # ABSTRACT: Higher-level UA features for HTTP::Tiny
-our $VERSION = '0.002'; # VERSION
+
+our $VERSION = '0.003';
 
 use superclass 'HTTP::Tiny' => 0.036;
 
 use HTTP::Tiny::UA::Response;
 
-# =method new
-#
-#     $http = HTTP::Tiny::UA->new( %attributes );
-#
-# This is inherited from L<HTTP::Tiny>.  The only difference so far is that
-# C<agent> will be C<HTTP-Tiny-UA/$VERSION>.
-#
-# =for :list
-# * C<agent>
-# A user-agent string (defaults to 'HTTP-Tiny-UA/$VERSION'). If C<agent> ends in a space character, the default user-agent string is appended.
-# * C<cookie_jar>
-# An instance of L<HTTP::CookieJar> or equivalent class that supports the C<add> and C<cookie_header> methods
-# * C<default_headers>
-# A hashref of default headers to apply to requests
-# * C<local_address>
-# The local IP address to bind to
-# * C<max_redirect>
-# Maximum number of redirects allowed (defaults to 5)
-# * C<max_size>
-# Maximum response size (only when not using a data callback).  If defined,
-# responses larger than this will return an exception.
-# * C<proxy>
-# URL of a proxy server to use (default is C<$ENV{http_proxy}> if set)
-# * C<no_proxy>
-# List of domain suffixes that should not be proxied.  Must be a comma-separated string or an array reference. (default is C<$ENV{no_proxy}>)
-# * C<timeout>
-# Request timeout in seconds (default is 60)
-# * C<verify_SSL>
-# A boolean that indicates whether to validate the SSL certificate of an C<https>
-# connection (default is false)
-# * C<SSL_options>
-# A hashref of C<SSL_*> options to pass through to L<IO::Socket::SSL>
-#
-# See L<SSL SUPPORT in HTTP::Tiny|HTTP::Tiny/SSL SUPPORT> for more on the
-# C<verify_SSL> and C<SSL_options> attributes.
-#
-# =method get|head|put|post|post_form|mirror|delete
-#
-# These methods are inherited from L<HTTP::Tiny> and work the same, except they
-# invoke the L<HTTP::Tiny::UA request|/request> method and return a
-# L<HTTP::Tiny::UA::Response> object.
-#
-# =method request
-#
-#     my $res = HTTP::Tiny->new->get( $url );
-#
-# Just like L<HTTP::Tiny::request|HTTP::Tiny/request>, but returns a
-# L<HTTP::Tiny::UA::Reponse> object.  All other C<get>, C<post>, etc. methods
-# eventually invoke this one so all such methods return response objects now.
-#
-# =cut
+#pod =method new
+#pod
+#pod     $http = HTTP::Tiny::UA->new( %attributes );
+#pod
+#pod This is inherited from L<HTTP::Tiny>.  The only difference so far is that
+#pod C<agent> will be C<HTTP-Tiny-UA/$VERSION>.
+#pod
+#pod =for :list
+#pod * C<agent>
+#pod A user-agent string (defaults to 'HTTP-Tiny-UA/$VERSION'). If C<agent> ends in a space character, the default user-agent string is appended.
+#pod * C<cookie_jar>
+#pod An instance of L<HTTP::CookieJar> or equivalent class that supports the C<add> and C<cookie_header> methods
+#pod * C<default_headers>
+#pod A hashref of default headers to apply to requests
+#pod * C<local_address>
+#pod The local IP address to bind to
+#pod * C<max_redirect>
+#pod Maximum number of redirects allowed (defaults to 5)
+#pod * C<max_size>
+#pod Maximum response size (only when not using a data callback).  If defined,
+#pod responses larger than this will return an exception.
+#pod * C<proxy>
+#pod URL of a proxy server to use (default is C<$ENV{http_proxy}> if set)
+#pod * C<no_proxy>
+#pod List of domain suffixes that should not be proxied.  Must be a comma-separated string or an array reference. (default is C<$ENV{no_proxy}>)
+#pod * C<timeout>
+#pod Request timeout in seconds (default is 60)
+#pod * C<verify_SSL>
+#pod A boolean that indicates whether to validate the SSL certificate of an C<https>
+#pod connection (default is false)
+#pod * C<SSL_options>
+#pod A hashref of C<SSL_*> options to pass through to L<IO::Socket::SSL>
+#pod
+#pod See L<SSL SUPPORT in HTTP::Tiny|HTTP::Tiny/SSL SUPPORT> for more on the
+#pod C<verify_SSL> and C<SSL_options> attributes.
+#pod
+#pod =method get|head|put|post|post_form|mirror|delete
+#pod
+#pod These methods are inherited from L<HTTP::Tiny> and work the same, except they
+#pod invoke the L<HTTP::Tiny::UA request|/request> method and return a
+#pod L<HTTP::Tiny::UA::Response> object.
+#pod
+#pod =method request
+#pod
+#pod     my $res = HTTP::Tiny->new->get( $url );
+#pod
+#pod Just like L<HTTP::Tiny::request|HTTP::Tiny/request>, but returns a
+#pod L<HTTP::Tiny::UA::Response> object.  All other C<get>, C<post>, etc. methods
+#pod eventually invoke this one so all such methods return response objects now.
+#pod
+#pod =cut
 
 sub request {
     my ( $self, @args ) = @_;
@@ -85,7 +85,7 @@ HTTP::Tiny::UA - Higher-level UA features for HTTP::Tiny
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -194,7 +194,7 @@ L<HTTP::Tiny::UA::Response> object.
     my $res = HTTP::Tiny->new->get( $url );
 
 Just like L<HTTP::Tiny::request|HTTP::Tiny/request>, but returns a
-L<HTTP::Tiny::UA::Reponse> object.  All other C<get>, C<post>, etc. methods
+L<HTTP::Tiny::UA::Response> object.  All other C<get>, C<post>, etc. methods
 eventually invoke this one so all such methods return response objects now.
 
 =for Pod::Coverage BUILD
@@ -273,6 +273,12 @@ L<https://github.com/dagolden/HTTP-Tiny-UA>
 
 David Golden <dagolden@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Graham Ollis
+
+Graham Ollis <perl@wdlabs.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2013 by David Golden.
